@@ -173,7 +173,7 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "NEGATE_LONG",
     "NEGATE_FLOAT",
     "NEGATE_DOUBLE",
-    "CONCAT",
+    "STRING_CONCAT",
     "BOOL_CONVERSION_INT",
     "BOOL_CONVERSION_LONG",
     "BOOL_CONVERSION_FLOAT",
@@ -181,47 +181,47 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "BOOL_CONVERSION_OBJECT",
     "BOOL_CONVERSION_REF",
     "BOOL_CONVERSION_BOOL_OBJECT",
-    "EQ_INT",
-    "EQ_LONG",
-    "EQ_FLOAT",
-    "EQ_DOUBLE",
-    "EQ_OBJECT",
-    "EQ_REF",
-    "NE_INT",
-    "NE_LONG",
-    "NE_FLOAT",
-    "NE_DOUBLE",
-    "NE_OBJECT",
-    "NE_REF",
-    "GT_INT",
-    "GT_LONG",
-    "GT_FLOAT",
-    "GT_DOUBLE",
-    "GE_INT",
-    "GE_LONG",
-    "GE_FLOAT",
-    "GE_DOUBLE",
-    "LT_INT",
-    "LT_LONG",
-    "LT_FLOAT",
-    "LT_DOUBLE",
-    "LE_INT",
-    "LE_LONG",
-    "LE_FLOAT",
-    "LE_DOUBLE",
-    "CMP_INT",
-    "CMP_LONG",
-    "CMP_FLOAT",
-    "CMP_DOUBLE",
+    "NUMERIC_COMPARISON_EQ_INT",
+    "NUMERIC_COMPARISON_EQ_LONG",
+    "NUMERIC_COMPARISON_EQ_FLOAT",
+    "NUMERIC_COMPARISON_EQ_DOUBLE",
+    "NUMERIC_COMPARISON_EQ_OBJECT",
+    "NUMERIC_COMPARISON_EQ_REF",
+    "NUMERIC_COMPARISON_NE_INT",
+    "NUMERIC_COMPARISON_NE_LONG",
+    "NUMERIC_COMPARISON_NE_FLOAT",
+    "NUMERIC_COMPARISON_NE_DOUBLE",
+    "NUMERIC_COMPARISON_NE_OBJECT",
+    "NUMERIC_COMPARISON_NE_REF",
+    "NUMERIC_COMPARISON_GT_INT",
+    "NUMERIC_COMPARISON_GT_LONG",
+    "NUMERIC_COMPARISON_GT_FLOAT",
+    "NUMERIC_COMPARISON_GT_DOUBLE",
+    "NUMERIC_COMPARISON_GE_INT",
+    "NUMERIC_COMPARISON_GE_LONG",
+    "NUMERIC_COMPARISON_GE_FLOAT",
+    "NUMERIC_COMPARISON_GE_DOUBLE",
+    "NUMERIC_COMPARISON_LT_INT",
+    "NUMERIC_COMPARISON_LT_LONG",
+    "NUMERIC_COMPARISON_LT_FLOAT",
+    "NUMERIC_COMPARISON_LT_DOUBLE",
+    "NUMERIC_COMPARISON_LE_INT",
+    "NUMERIC_COMPARISON_LE_LONG",
+    "NUMERIC_COMPARISON_LE_FLOAT",
+    "NUMERIC_COMPARISON_LE_DOUBLE",
+    "NUMERIC_COMPARISON_CMP_INT",
+    "NUMERIC_COMPARISON_CMP_LONG",
+    "NUMERIC_COMPARISON_CMP_FLOAT",
+    "NUMERIC_COMPARISON_CMP_DOUBLE",
     "IS_UNDEF",
     "IS_NOT_UNDEF",
-    "STRING_EQ",
-    "STRING_NE",
-    "STRING_GT",
-    "STRING_GE",
-    "STRING_LT",
-    "STRING_LE",
-    "STRING_CMP",
+    "STRING_COMPARISON_EQ",
+    "STRING_COMPARISON_NE",
+    "STRING_COMPARISON_GT",
+    "STRING_COMPARISON_GE",
+    "STRING_COMPARISON_LT",
+    "STRING_COMPARISON_LE",
+    "STRING_COMPARISON_CMP",
     "NEW_OBJECT",
     "NEW_OBJECT_ARRAY",
     "NEW_MULDIM_ARRAY",
