@@ -1,6 +1,6 @@
 =head1 Name
 
-SPVM::Document::Language::Types - Types in The SPVM Language
+SPVM::Document::Language::Types - Types in the SPVM Language
 
 =head1 Description
 
@@ -52,6 +52,15 @@ The length of the string can be got using a L<string length operator|/"String Le
   my $message = "Hello"+
   my $length = length $message;
 
+At the L<native level|SPVM::Document::NativeClass>, the character just after the last character of the string is set to C<\0>, so the characters in the string can be used as a C language string.
+
+  # The characters in the string can be used as a C language string
+  void* obj_string = stack[0].oval;
+  const char* chars = env->get_chars(env, stack, obj_string);
+  if (strcmp(chars, "Hello") == 0) {
+    
+  }
+  
 =head2 Array
 
 The array is the data structure for multiple values.
@@ -123,23 +132,21 @@ A object is created by the L<new|SPVM::Document::Language::Operators/"new"> oper
 
 =head2 Undefined Value
 
-An undefined value is represented by C<undef>.
+An undefined value is created by the L<undef|SPVM::Document::Language::Operators/"undef Operator"> operator.
 
   undef
 
-An undefined value can be assigned to an L<object type|/"Object Types">.
+The type of an undefined value is the L<undef type|/"undef Type">.
 
-In the level of L<native APIs|SPVM:Document::NativeAPI>, undef is defined as C<(void*)NULL>.
+An undefined value is able to be assigned to an L<object type|/"Object Types">.
 
-  (void*)NULL
-
-An undefined value can be compared by the C<==> operator and the C<!=> operator. An undefined value is guaranteed not to be equal to the any created object.
-
-The type of undef is L<undef type|/"undef Type">
+In L<native classes|SPVM::Document::NativeClass>, an undefined value is equal to 0, normally a null pointer C<NULL> defined in C<stddef.h>.
+  
+  NULL
 
 Examples:
   
-  # Undefine values
+  # Examples of undefined values
   my $string : string = undef;
   
   if (undef) {
@@ -151,11 +158,11 @@ Examples:
     
   }
 
-=head3 Reference
+=head2 Reference
 
 The reference is the address of a L<local variable|/"Local Variable"> on the memory.
 
-=head4 Creating Reference
+=head3 Creating Reference
 
 The L<reference operator|/"Reference Operator"> creates the reference of a L<local variable|/"Local Variable">.
 
@@ -475,7 +482,7 @@ Note that interface types are not L<class types|/"Class Type"> although they are
 
 =head3 Any Object Type
 
-Any Object Type is represented by "object". Designed to represent the "void *" Type in C.
+Any object type is represented by "object". Designed to represent the "void *" type in C.
 
   my $object: object;
 
@@ -493,11 +500,11 @@ Basic types are L<numeric types|/"Numeric Types">, L<multi-numeric types|/"Multi
 
 =head2 undef Type
 
-The undef type is the type of L<undef|/"Undefined Value"> value.
+The undef type is the type of an L<undefined value|/"Undefined Value">.
 
 =head2 void Type
 
-B<void Type> is a special Type that can only be used in the return type of the L<method definition|/"Method Definition"> and indicates the method has no return value.
+B<void Type> is a special type that can only be used in the return type of the L<method definition|/"Method Definition"> and indicates the method has no return value.
 
   void
 
@@ -643,7 +650,7 @@ The any object array type C<object[]> is the type that any L<object array type|/
   my $array : object[] = new object[3];
   my $array : object[] = new Point[][3];
 
-Any Object Array Type is an L<array type|/"Array Types">.
+Any object array type is an L<array type|/"Array Types">.
 
 You can get the array length using the L<array length operator|/"The array Length Operator">.
 
@@ -772,7 +779,7 @@ See L</"Setting Multi-Numeric Field"> to set the field of the multi-numeric valu
 
 =head2 Reference Type
 
-Reference Type is a Type that can store the address of a variable. Add C<*> after a L<numeric type|/"Numeric Types"> or the L<multi-numeric type|/"Multi-Numeric Types"> You can define it.
+Reference type is a type that can store the address of a variable. Add C<*> after a L<numeric type|/"Numeric Types"> or the L<multi-numeric type|/"Multi-Numeric Types"> You can define it.
 
   my $num : int;
   my $num_ref : int* = \$num;
@@ -782,31 +789,31 @@ Reference Type is a Type that can store the address of a variable. Add C<*> afte
 
 Only the address of the Local Variable acquired by L</"Reference Operator"> can be assigned to the value of Reference Type.
 
-Reference Type can be used as Type of argument in the L<method definition|/"Method Definition">.
+Reference type can be used as type of argument in the L<method definition|/"Method Definition">.
 
-Reference Type cannot be used as return value Type in the L<method definition|/"Method Definition">.
+Reference type cannot be used as return value type in the L<method definition|/"Method Definition">.
 
-Reference Type cannot be used as the field type in the L<class definition|/"Class Definition">.
+Reference type cannot be used as the field type in the L<class definition|/"Class Definition">.
 
-Reference Type cannot be used as the type of Class Variable in the L<class definition|/"Class Definition">.
+Reference type cannot be used as the type of Class Variable in the L<class definition|/"Class Definition">.
 
 See L</"Reference"> for a detailed explanation of Reference.
 
 Compilation Errors:
 
-If only Local Variable Declaration of Reference Type is performed, a compilation error occurs
+If only Local Variable Declaration of Reference type is performed, a compilation error occurs
 
-Reference Type can be used as Type of the L<local variable declaration|/"Local Variable Declaration">. The address of the Local Variable must be stored by the Reference Operator. In case of only Local Variable Declaration, a compilation error occurs
+Reference type can be used as type of the L<local variable declaration|/"Local Variable Declaration">. The address of the Local Variable must be stored by the Reference Operator. In case of only Local Variable Declaration, a compilation error occurs
 
-If the Reference Type is used at an Invalid location, a compilation error occurs
+If the Reference type is used at an Invalid location, a compilation error occurs
 
 =head3 Numeric Reference Type
 
-Numeric Reference Type means a L<numeric type|/"Numeric Types"> for a L<reference type|/"Reference Type">. Says.
+Numeric Reference type means a L<numeric type|/"Numeric Types"> for a L<reference type|/"Reference Type">. Says.
 
 =head3 Multi-Numeric Reference Type
 
-Multi-Numeric Reference Type means a L<reference type|/"Reference Type"> for the L<multi-numeric type|/"Multi-Numeric Types"> variables. > Means.
+Multi-Numeric Reference type means a L<reference type|/"Reference Type"> for the L<multi-numeric type|/"Multi-Numeric Types"> variables. > Means.
 
 =head2 Type Qualifiers
 
@@ -920,7 +927,7 @@ If the type is a multi-numeric type, it is the length of the fields, owhterwise
 
 =head1 Type Inference
 
-Omitting the L<type|/"Types"> when the L<local variable declaration|/"Local Variable Declaration"> by Type Inference can. Type Inference is always performed by the type on the Right side of Assignment Operator.
+Omitting the L<type|/"Types"> when the L<local variable declaration|/"Local Variable Declaration"> by type Inference can. Type Inference is always performed by the type on the Right side of Assignment Operator.
 
   # int
   my $num = 1;
@@ -1446,16 +1453,16 @@ Otherwise, the assignment requirement is false.
 
 <table>
   <tr><th>Assignment Requirement</th><th>To</th><th>From</th><th><a href="#Implicite-Type-Conversion">Implicite Type Conversion</a></th></tr>
-  <tr><td>True</td><td>X[]..[]</td><td>X[]..[]</td><td>None</td></tr>
+  <tr><td>True</td><td>X[]..</td><td>X[]..</td><td>None</td></tr>
   <tr><td>True</td><td>object[]</td><td>undef</td><td>None</td></tr>
-  <tr><td>True</td><td>SUPER_CLASS_X[]..[]</td><td>CLASS_Y[]..[]</td><td>None</td></tr>
-  <tr><td>True</td><td>INTERFACE_X[]..[]</td><td>INTERFACE_HAVING_Y[]..[]</td><td>None</td></tr>
+  <tr><td>True</td><td>SUPER_CLASS_X[]..</td><td>CLASS_Y[]..</td><td>None</td></tr>
+  <tr><td>True</td><td>INTERFACE_X[]..</td><td>INTERFACE_HAVING_Y[]..</td><td>None</td></tr>
   <tr><td>False</td><td>object[]</td><td>OTHER</td><td>None</td></tr>
 </table>
 
 =end html
 
-(C<[]..[]> means two or more C<[]>)
+(C<[]..> means one or more C<[]>)
 
 Examples:
 
@@ -2088,19 +2095,19 @@ Otherwise, the cast requirement is false.
 
 <table>
   <tr><th>Cast Requirement</th><th>To</th><th>From</th><th><a href="#Type-Conversion">Conversion or Type Checking</a></th></tr>
-  <tr><td>True</td><td>ANY_X[]..[]</td><td>ANY_X[]..[]</td><td>None</td></tr>
-  <tr><td>True</td><td>ANY_X[]..[]</td><td>object</td><td><a href="#Runtime-Type-Checking">Runtime type checking</a></td></tr>
-  <tr><td>True</td><td>ANY_X[]..[]</td><td>object[]</td><td><a href="#Runtime-Type-Checking">Runtime type checking</a></td></tr>
-  <tr><td>True</td><td>ANY_X[]..[]</td><td>undef</td><td>None</td></tr>
-  <tr><td>True</td><td>SUPER_CLASS_X[]..[]</td><td>CLASS_Y[]..[]</td><td>None</td></tr>
-  <tr><td>True</td><td>CLASS_X[]..[]</td><td>SUPER_CLASS_Y[]..[]</td><td><a href="#Runtime-Type-Checking">Runtime type checking</a></td></tr>
-  <tr><td>True</td><td>INTERFACE_X[]..[]</td><td>INTERFACE_HAVING_Y[]..[]</td><td>None</td></tr>
+  <tr><td>True</td><td>ANY_X[]..</td><td>ANY_X[]..</td><td>None</td></tr>
+  <tr><td>True</td><td>ANY_X[]..</td><td>object</td><td><a href="#Runtime-Type-Checking">Runtime type checking</a></td></tr>
+  <tr><td>True</td><td>ANY_X[]..</td><td>object[]</td><td><a href="#Runtime-Type-Checking">Runtime type checking</a></td></tr>
+  <tr><td>True</td><td>ANY_X[]..</td><td>undef</td><td>None</td></tr>
+  <tr><td>True</td><td>SUPER_CLASS_X[]..</td><td>CLASS_Y[]..</td><td>None</td></tr>
+  <tr><td>True</td><td>CLASS_X[]..</td><td>SUPER_CLASS_Y[]..</td><td><a href="#Runtime-Type-Checking">Runtime type checking</a></td></tr>
+  <tr><td>True</td><td>INTERFACE_X[]..</td><td>INTERFACE_HAVING_Y[]..</td><td>None</td></tr>
   <tr><td>False</td><td>object[]</td><td>OTHER</td><td>None</td></tr>
 </table>
 
 =end html
 
-(C<[]..[]> means two or more C<[]>)
+(C<[]..> means one or more C<[]>)
 
 Examples:
 
@@ -2384,7 +2391,7 @@ The String-to-byte conversion is a L<type conversion|/"Type Conversion"> from th
   my $string : string = "Hello";
   my $num : byte = (byte)$string;
 
-If the string is C<undef>, returns 0.
+If the string is not defined, returns 0.
 
 If not, the string is coverted to a number by the C<strtoll> function in the C language.
 
@@ -2402,7 +2409,7 @@ The String-to-short conversion is a L<type conversion|/"Type Conversion"> from t
   my $string : string = "Hello";
   my $num : short = (short)$string;
 
-If the string is C<undef>, returns 0.
+If the string is not defined, returns 0.
 
 If not, the string is coverted to a number by the C<strtoll> function in the C language.
 
@@ -2420,7 +2427,7 @@ The String-to-int conversion is a L<type conversion|/"Type Conversion"> from the
   my $string : string = "Hello";
   my $num : int = (int)$string;
 
-If the string is C<undef>, returns 0.
+If the string is not defined, returns 0.
 
 If not, the string is coverted to a number by the C<strtoll> function in the C language.
 
@@ -2438,7 +2445,7 @@ The String-to-long conversion is a L<type conversion|/"Type Conversion"> from th
   my $string : string = "Hello";
   my $num : long = (long)$string;
 
-If the string is C<undef>, returns 0.
+If the string is not defined, returns 0.
 
 If not, the string is coverted to a number by the C<strtoll> function in the C language.
 
@@ -2452,7 +2459,7 @@ The String-to-float conversion is a L<type conversion|/"Type Conversion"> from t
   my $string : string = "Hello";
   my $float : float = (float)$string;
 
-If the string is C<undef>, returns 0.
+If the string is not defined, returns 0.
 
 If not, the string is coverted to a number by the C<strtof> function in the C language.
 
@@ -2466,7 +2473,7 @@ The String-to-double conversion is a L<type conversion|/"Type Conversion"> from
   my $string : string = "Hello";
   my $num : double = (double)$string;
 
-If the string is C<undef>, returns 0.
+If the string is not defined, returns 0.
 
 If not, the string is coverted to a number by the C<strtod> function in the C language.
 
@@ -2661,16 +2668,16 @@ If the type of distribution is an L<interface type|/"Interface Type">, an L<inte
   <tr><td>True</td><td>object[]</td><td>OBJECT_ARRAY_Y</td></tr>
   <tr><td>True</td><td>SUPER_CLASS_X</td><td>CLASS_Y</td></tr>
   <tr><td>True</td><td>SUPER_CLASS_X[]</td><td>CLASS_Y[]</td></tr>
-  <tr><td>True</td><td>SUPER_CLASS_X[]..[]</td><td>CLASS_Y[]..[]</td></tr>
+  <tr><td>True</td><td>SUPER_CLASS_X[]..</td><td>CLASS_Y[]..</td></tr>
   <tr><td>True</td><td>INTERFACE_X</td><td>INTERFACE_HAVING_Y</td></tr>
   <tr><td>True</td><td>INTERFACE_X[]</td><td>INTERFACE_HAVING_Y[]</td></tr>
-  <tr><td>True</td><td>INTERFACE_X[]..[]</td><td>INTERFACE_HAVING_Y[]..[]</td></tr>
+  <tr><td>True</td><td>INTERFACE_X[]..</td><td>INTERFACE_HAVING_Y[]..</td></tr>
   <tr><td>False</td><td>OBJECT_X</td><td>OTHER</td></tr>
 </table>
 
 =end html
 
-(C<[]..[]> means two or more C<[]>)
+(C<[]..> means one or more C<[]>)
 
 =head1 Type Comment
 
